MSRC(Microsoft Security Research Center) API for python
============================================

Installation
------------
	pip install msrc

Requirements
-----------
* requests


Usage
-----
	# Search with CVE
	python msrc.py CVE-2018-8174
	# Search with KB
	python msrc.py KB5014699